@@ -18,7 +18,7 @@ class DefaultExceptionHandler:
     def __init__(self, app):
         self.app = app
         self.errors_env = Environment(
-            loader=FileSystemLoader(str(pathlib.Path("selfpages").absolute())))
+            loader=FileSystemLoader("arc/selfpages"))
 
     def handle_error(self, request, response, error):
         response.status_code = 500
@@ -30,6 +30,6 @@ class DefaultExceptionHandler:
     def handle_404(self, response):
         response.status_code = 404
         
-        response.body = self.errors_env.get_template("error-404.html").render().encode()
+        response.body = self.errors_env.get_template("index.html").render().encode()
 
 
